===============
Getting started
===============

.. toctree::
    :maxdepth: 1
    :hidden:

    installation
    5_minutes_to_zfit
    ../tutorials/introduction


Welcome to zfit!

How to set it up: :ref:`Installing zfit <zfit_installation>`


:ref:`Quickstart: 5 minutes to zfit <5-minutes-to-zfit>`

A more complete introduction to zfit can be found :ref:`in the introduction section.<introduction_tutorial>`

For a throughout explanation see the :ref:`tutorial_section`. Some of tutorials are also available in the
`zfit youtube channel <https://www.youtube.com/channel/UC_IOWLYdQSkWr54K-o8BTCA>`_
